==> haskell-ci-0.10.3-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ci.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-haskell-ci-z-haskell-ci-internal
version:              0.10.3
package-name:         haskell-ci
lib-name:             haskell-ci-internal
id:
    haskell-ci-0.10.3-8aCZ2bXGN5MAOnpBJuoGCF-haskell-ci-internal

key:
    haskell-ci-0.10.3-8aCZ2bXGN5MAOnpBJuoGCF-haskell-ci-internal

license:              GPL-3.0-or-later
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Cabal package script generator for Travis-CI
description:
    Script generator (@haskell-ci@) for [Travis-CI](https://travis-ci.org/) for continuous-integration testing of Haskell Cabal packages.

    Included features (not limited to):

    * Multiple GHC support
    * Dependency caching
    * cabal.project support (see [Nix-style local builds documentation](https://cabal.readthedocs.io/en/latest/nix-local-build-overview.html))
    * Runs tests and builds benchmarks
    * Generates Haddocks
    * macOS (OSX) support
    * GHCJS support
    * building with specific constraints

    === Quick Start Guide

    Add a @tested-with@ line to your @.cabal@ file (e.g. @tested-with: GHC == 8.0.2 || == 8.2.2@) and then run @haskell-ci yourpackage.cabal -o .travis.yml@ to generate the Travis-CI job script.

    See @haskell-ci --help@ for more information.

category:             Development
abi:                  55b40ca0ba6501dc45ac3ae258febbe0
exposed-modules:
    HaskellCI HaskellCI.Cli HaskellCI.Compiler HaskellCI.Config
    HaskellCI.Config.ConstraintSet HaskellCI.Config.CopyFields
    HaskellCI.Config.Doctest HaskellCI.Config.Dump
    HaskellCI.Config.Folds HaskellCI.Config.HLint
    HaskellCI.Config.Installed HaskellCI.Config.Jobs
    HaskellCI.Config.PackageScope HaskellCI.Config.Ubuntu
    HaskellCI.Diagnostics HaskellCI.Jobs HaskellCI.List
    HaskellCI.MonadErr HaskellCI.Newtypes HaskellCI.OptionsGrammar
    HaskellCI.OptparseGrammar HaskellCI.Package HaskellCI.ParsecUtils
    HaskellCI.Prelude HaskellCI.Sh HaskellCI.ShVersionRange
    HaskellCI.TestedWith HaskellCI.Tools HaskellCI.Travis
    HaskellCI.Travis.Yaml HaskellCI.VersionInfo HaskellCI.YamlSyntax

import-dirs:          /usr/lib/ghc-8.10.2/site-local/haskell-ci-0.10.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/haskell-ci-0.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/haskell-ci-0.10.3
hs-libraries:
    HShaskell-ci-0.10.3-8aCZ2bXGN5MAOnpBJuoGCF-haskell-ci-internal

depends:
    Cabal-3.2.0.0 HsYAML-0.2.1.0-2Vd9sWslsVBGBWDLU0qKDA
    ShellCheck-0.7.1-3y6IeeCiVkbESvV9V4Zj58
    aeson-1.5.4.1-4wEKZPgDVdkFlnmRCF3GfK base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.10.0
    cabal-install-parsers-0.3.0.1-4069mHfPp8YEdVbcB9ShVn
    containers-0.6.2.1 deepseq-1.4.4.0 directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    generic-lens-lite-0.1-6c9NdqTQFs5HTRkDu8fyHv
    lattices-2.0.2-2tN0zrARNRXHII8izqJRAQ mtl-2.2.2
    network-uri-2.6.3.0-9Euob0KzSqAJeAtMbRfaKH
    optparse-applicative-0.16.1.0-APkj483CtTi90pIMnK6FzL
    parsec-3.1.14.0 pretty-1.1.3.6 process-1.6.9.0
    temporary-1.3-7XI7e3uvK8m9UJfnfo9Yw text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-7jajDWNmlIpBHz95ShzOz6

haddock-interfaces:   /usr/share/doc/haskell-ci/html/haskell-ci.haddock
haddock-html:         /usr/share/doc/haskell-ci/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ci-0.10.3-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ci.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-haskell-ci-z-haskell-ci-internal
version:              0.10.3
package-name:         haskell-ci
lib-name:             haskell-ci-internal
id:
    haskell-ci-0.10.3-Fdjd6JGmUlX2RjwGCQ5TdL-haskell-ci-internal

key:
    haskell-ci-0.10.3-Fdjd6JGmUlX2RjwGCQ5TdL-haskell-ci-internal

license:              GPL-3.0-or-later
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Cabal package script generator for Travis-CI
description:
    Script generator (@haskell-ci@) for [Travis-CI](https://travis-ci.org/) for continuous-integration testing of Haskell Cabal packages.

    Included features (not limited to):

    * Multiple GHC support
    * Dependency caching
    * cabal.project support (see [Nix-style local builds documentation](https://cabal.readthedocs.io/en/latest/nix-local-build-overview.html))
    * Runs tests and builds benchmarks
    * Generates Haddocks
    * macOS (OSX) support
    * GHCJS support
    * building with specific constraints

    === Quick Start Guide

    Add a @tested-with@ line to your @.cabal@ file (e.g. @tested-with: GHC == 8.0.2 || == 8.2.2@) and then run @haskell-ci yourpackage.cabal -o .travis.yml@ to generate the Travis-CI job script.

    See @haskell-ci --help@ for more information.

category:             Development
abi:                  ba73bc9e4288b55c71f7bc99bc27f811
exposed-modules:
    HaskellCI HaskellCI.Cli HaskellCI.Compiler HaskellCI.Config
    HaskellCI.Config.ConstraintSet HaskellCI.Config.CopyFields
    HaskellCI.Config.Doctest HaskellCI.Config.Dump
    HaskellCI.Config.Folds HaskellCI.Config.HLint
    HaskellCI.Config.Installed HaskellCI.Config.Jobs
    HaskellCI.Config.PackageScope HaskellCI.Config.Ubuntu
    HaskellCI.Diagnostics HaskellCI.Jobs HaskellCI.List
    HaskellCI.MonadErr HaskellCI.Newtypes HaskellCI.OptionsGrammar
    HaskellCI.OptparseGrammar HaskellCI.Package HaskellCI.ParsecUtils
    HaskellCI.Prelude HaskellCI.Sh HaskellCI.ShVersionRange
    HaskellCI.TestedWith HaskellCI.Tools HaskellCI.Travis
    HaskellCI.Travis.Yaml HaskellCI.VersionInfo HaskellCI.YamlSyntax

import-dirs:          /usr/lib/ghc-8.10.2/site-local/haskell-ci-0.10.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/haskell-ci-0.10.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/haskell-ci-0.10.3
hs-libraries:
    HShaskell-ci-0.10.3-Fdjd6JGmUlX2RjwGCQ5TdL-haskell-ci-internal

depends:
    Cabal-3.2.0.0 HsYAML-0.2.1.0-3tyw7NdRW0EDchodoMHxQj
    ShellCheck-0.7.1-LH7Yvc89Zib4ImwKCalsJP
    aeson-1.5.4.1-7Fmt2H1B65wDOTuTXG6T4t base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 bytestring-0.10.10.0
    cabal-install-parsers-0.4-Fatfpa9PbD3FDNHj1UdFmt containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 exceptions-0.10.4
    filepath-1.4.2.1 generic-lens-lite-0.1-6c9NdqTQFs5HTRkDu8fyHv
    lattices-2.0.2-K64NuFiSadzFxkC0RBeg5J mtl-2.2.2
    network-uri-2.6.3.0-FlqrnWVT6WpD3H028R3hh1
    optparse-applicative-0.16.1.0-GSwLI83C9XBKGiBD9OfNoW
    parsec-3.1.14.0 pretty-1.1.3.6 process-1.6.9.0
    temporary-1.3-BDCNcU0AEAULr3FqoHUZJf text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-2nDlvtn1IciJcNnZKP7xpJ

haddock-interfaces:   /usr/share/doc/haskell-ci/html/haskell-ci.haddock
haddock-html:         /usr/share/doc/haskell-ci/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
